ids

package
v0.0.0-...-a10a6d9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 29, 2025 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsValidUUID

func IsValidUUID(id string) bool

IsValidUUID checks if a string is a valid UUID

func NewEntityID

func NewEntityID() string

NewEntityID generates a new UUID7 for any entity (players, items, rooms, etc.)

func RandStringRunes

func RandStringRunes(n int) string

RandStringRunes generates a random string of specified length using letters

Types

This section is empty.

Jump to